==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder extends EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluentImpl<EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder> implements VisitableBuilder<EnvoyFilterRouteConfigurationMatchVirtualHostMatch,EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder>{
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder() {
    this(false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterRouteConfigurationMatchVirtualHostMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterRouteConfigurationMatchVirtualHostMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withRoute(instance.getRoute());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withRoute(instance.getRoute());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatch build() {
    EnvoyFilterRouteConfigurationMatchVirtualHostMatch buildable = new EnvoyFilterRouteConfigurationMatchVirtualHostMatch(fluent.getName(),fluent.getRoute());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder extends EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder> implements VisitableBuilder<EnvoyFilterRouteConfigurationMatchVirtualHostMatch,EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder>{
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder() {
    this(false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterRouteConfigurationMatchVirtualHostMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterRouteConfigurationMatchVirtualHostMatch(), validationEnabled);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent,EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterRouteConfigurationMatchVirtualHostMatch());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withRoute(instance.getRoute());
      fluent.withName(instance.getName());
      fluent.withRoute(instance.getRoute());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance) {
    this(instance,false);
  }
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatchBuilder(EnvoyFilterRouteConfigurationMatchVirtualHostMatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterRouteConfigurationMatchVirtualHostMatch());

    if (instance != null) {
      this.withName(instance.getName());
      this.withRoute(instance.getRoute());
      this.withName(instance.getName());
      this.withRoute(instance.getRoute());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterRouteConfigurationMatchVirtualHostMatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterRouteConfigurationMatchVirtualHostMatch build() {
    EnvoyFilterRouteConfigurationMatchVirtualHostMatch buildable = new EnvoyFilterRouteConfigurationMatchVirtualHostMatch(fluent.getName(),fluent.buildRoute());
    return buildable;
  }
  
}
